@@ -1,9 +1,7 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use Opt::Imistic (
-    demand => [ 'o' ]
-);
+use Opt::Imistic ([ 'o' ]);
 use Data::Dumper;
 
 print Dumper (\%ARGV);
